@@ -321,4 +321,29 @@ class Server():
             if not recursive:
                 break
 
-        return result
\ No newline at end of file
+        return result
+
+    def get_abs_path(self, file_name: str, dest_dir: str) -> Optional[str]:
+        """
+        在指定目录下查找指定文件名的文件，并返回第一个找到的文件的绝对路径
+
+        参数:
+            file_name: 要查找的文件名（包含后缀）
+            dest_dir: 要搜索的目标目录
+
+        返回:
+            找到的文件的绝对路径；如果未找到或发生错误则返回None
+        """
+        # 验证目标目录是否存在且是有效目录
+        if not os.path.isdir(dest_dir):
+            return None
+
+        # 遍历目标目录下的所有文件和子目录
+        for root, _, files in os.walk(dest_dir):
+            # 检查当前目录下是否存在目标文件
+            if file_name in files:
+                # 构建并返回绝对路径
+                return os.path.abspath(os.path.join(root, file_name))
+
+        # 遍历结束仍未找到文件
+        return None
\ No newline at end of file
